@@ -1,5 +1,6 @@
 import signal
 import sys
+from typing import Any
 
 from hpcrocket.cli import parse_cli_args
 from hpcrocket.core.application import Application
@@ -8,14 +9,16 @@ from hpcrocket.ssh.sshexecutor import SSHExecutor
 from hpcrocket.ui import RichUI
 
 
-def main():
+def main() -> None:
     cli_args = parse_cli_args(sys.argv[1:])
     with RichUI() as ui:
-        executor_factory = SSHExecutor(cli_args.connection, cli_args.proxyjumps)
-        filesystem_factory = PyFilesystemFactory(cli_args)
-        app = Application(executor_factory, filesystem_factory, ui)
+        executor = SSHExecutor(cli_args.connection,
+                               cli_args.proxyjumps)
 
-        def on_cancel(*args, **kwargs):
+        filesystem_factory = PyFilesystemFactory(cli_args)
+        app = Application(executor, filesystem_factory, ui)
+
+        def on_cancel(*args: Any, **kwargs: Any) -> None:
             sys.exit(app.cancel())
 
         signal.signal(signal.SIGINT, on_cancel)
