@@ -1,5 +1,5 @@
 import threading
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING, Callable, Optional
 
 try:
     from typing import Protocol
@@ -13,16 +13,16 @@ if TYPE_CHECKING:
 
 class WatcherThread(Protocol):
 
-    def start(self):
+    def start(self) -> None:
         pass
 
-    def stop(self):
+    def stop(self) -> None:
         pass
 
     def is_done(self) -> bool:
         pass
 
-    def join(self):
+    def join(self, timeout: Optional[float] = None) -> None:
         pass
 
 
@@ -37,7 +37,6 @@ class WatcherThreadImpl(threading.Thread):
         self.interval = interval
         self.stop_event = threading.Event()
         self._done = False
-        self._joined = False
 
     def poll(self) -> None:
         last_job = None
